
IAM/SimpleDB authentication backend for Django
==============================================

.. toctree::

   setup
   usage
   settings
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
